@@ -66,15 +66,15 @@
 #endif /* HAVE_DIRENT_H */
 
 #include "common.h"
-#include "text_object.h"
+#include "content/text_object.h"
 
 #ifdef BUILD_WAYLAND
-#include "wl.h"
+#include "output/wl.h"
 #endif /* BUILD_WAYLAND */
 
 #ifdef BUILD_X11
-#include "x11-settings.h"
-#include "x11.h"
+#include "lua/x11-settings.h"
+#include "output/x11.h"
 
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wvariadic-macros"
@@ -101,57 +101,57 @@
 #endif /* BUILD_RSS */
 
 /* local headers */
-#include "colours.h"
+#include "content/colours.hh"
 #include "core.h"
-#include "diskio.h"
-#include "exec.h"
+#include "data/exec.h"
+#include "data/hardware/diskio.h"
 #ifdef BUILD_GUI
-#include "fonts.h"
-#include "gui.h"
+#include "lua/fonts.h"
+#include "output/gui.h"
 #endif /* BUILD_GUI */
-#include "fs.h"
+#include "data/fs.h"
 #ifdef BUILD_ICONV
-#include "iconv_tools.h"
+#include "data/iconv_tools.h"
 #endif /* BUILD_ICONV */
-#include "llua.h"
+#include "content/specials.h"
+#include "content/temphelper.h"
+#include "content/template.h"
+#include "data/network/mail.h"
+#include "data/network/net_stat.h"
+#include "data/timeinfo.h"
+#include "data/top.h"
 #include "logging.h"
-#include "mail.h"
-#include "nc.h"
-#include "net_stat.h"
-#include "specials.h"
-#include "temphelper.h"
-#include "template.h"
-#include "timeinfo.h"
-#include "top.h"
+#include "output/nc.h"
 
 #ifdef BUILD_MYSQL
-#include "mysql.h"
+#include "data/mysql.h"
 #endif /* BUILD_MYSQL */
 #ifdef BUILD_NVIDIA
-#include "nvidia.h"
+#include "data/hardware/nvidia.h"
 #endif /* BUILD_NVIDIA */
 #ifdef BUILD_CURL
-#include "ccurl_thread.h"
+#include "data/network/ccurl_thread.h"
 #endif /* BUILD_CURL */
 
-#include "display-output.hh"
-#include "lua-config.hh"
-#include "setting.hh"
+#include "lua/llua.h"
+#include "lua/lua-config.hh"
+#include "lua/setting.hh"
+#include "output/display-output.hh"
 
 /* check for OS and include appropriate headers */
 #if defined(__linux__)
-#include "linux.h"
+#include "data/os/linux.h"
 #elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
-#include "freebsd.h"
+#include "data/os/freebsd.h"
 #elif defined(__DragonFly__)
-#include "dragonfly.h"
+#include "data/os/dragonfly.h"
 #elif defined(__OpenBSD__)
-#include "openbsd.h"
+#include "data/os/openbsd.h"
 #elif defined(__NetBSD__)
-#include "netbsd.h"
+#include "data/os/netbsd.h"
 #endif
 
-#include "gradient.h"
+#include "content/gradient.hh"
 
 #ifdef BUILD_OLD_CONFIG
 #include "convertconf.h"
@@ -1398,8 +1398,10 @@ int draw_each_line_inner(char *s, int special_index, int last_special_applied) {
             }
 #ifdef BUILD_MATH
             if (show_graph_scale.get(*state) && (current->show_scale == 1)) {
-              // Set the foreground colour to the first colour, ensures the scale text is always drawn in the same colour
-              set_foreground_color(current->first_colour);
+              if (current->colours_set) {
+                  // Set the foreground colour to the first colour, ensures the scale text is always drawn in the same colour
+                  set_foreground_color(current->first_colour);
+              }
               int tmp_x = cur_x;
               int tmp_y = cur_y;
               cur_x += font_ascent() / 2;
@@ -1983,40 +1985,6 @@ void load_config_file() {
   lua::stack_sentry s(l);
   l.checkstack(2);
 
-  // Extend lua package.path so scripts can use relative paths
-  {
-    struct stat file_stat {};
-
-    std::string path_ext;
-
-    // add XDG directory to lua path
-    auto xdg_path =
-        std::filesystem::path(to_real_path(XDG_CONFIG_FILE)).parent_path();
-    if (stat(xdg_path.c_str(), &file_stat) == 0) {
-      path_ext.push_back(';');
-      path_ext.append(xdg_path);
-      path_ext.append("/?.lua");
-    }
-
-    auto parent_path = current_config.parent_path();
-    if (xdg_path != parent_path && stat(path_ext.c_str(), &file_stat) == 0) {
-      path_ext.push_back(';');
-      path_ext.append(parent_path);
-      path_ext.append("/?.lua");
-    }
-
-    l.getglobal("package");
-    l.getfield(-1, "path");
-
-    auto path = l.tostring(-1);
-    path.append(path_ext);
-    l.pop();
-    l.pushstring(path.c_str());
-
-    l.setfield(-2, "path");
-    l.pop();
-  }
-
   try {
 #ifdef BUILD_BUILTIN_CONFIG
     if (current_config == builtin_config_magic) {
@@ -2110,9 +2078,9 @@ void set_current_config() {
 const char *getopt_string =
     "vVqdDSs:t:u:i:hc:p:"
 #if defined(__linux__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || \
-    defined(__HAIKU__) || defined(__NetBSD__)
+    defined(__HAIKU__) || defined(__NetBSD__) || defined(__OpenBSD__)
     "U"
-#endif /* Linux || FreeBSD || Haiku || NetBSD */
+#endif /* Linux || FreeBSD || Haiku || NetBSD || OpenBSD */
 #ifdef BUILD_X11
     "x:y:w:a:X:m:f:"
 #ifdef OWN_WINDOW
@@ -2144,9 +2112,9 @@ const struct option longopts[] = {
     {"text", 1, nullptr, 't'},          {"interval", 1, nullptr, 'u'},
     {"pause", 1, nullptr, 'p'},
 #if defined(__linux__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || \
-    defined(__HAIKU__) || defined(__NetBSD__)
+    defined(__HAIKU__) || defined(__NetBSD__) || defined(__OpenBSD__)
     {"unique", 0, nullptr, 'U'},
-#endif /* Linux || FreeBSDi || Haiku || NetBSD */
+#endif /* Linux || FreeBSD || Haiku || NetBSD || OpenBSD */
     {nullptr, 0, nullptr, 0}
 };
 
@@ -2169,6 +2137,7 @@ void initialisation(int argc, char **argv) {
   set_default_configurations();
 
   set_current_config();
+  llua_init();
   load_config_file();
 
   /* handle other command line arguments */
