@@ -1,16 +1,14 @@
-import Fuse from 'fuse.js'
+import Fuse, { FuseResult } from 'fuse.js'
 import React, { Fragment, useCallback, useEffect, useState } from 'react'
 import { Search as SearchIcon } from 'react-feather'
-import { SearchItem } from '../utils/search'
+import { SearchIndex, SearchItem } from '../utils/search'
 import { Dialog, Transition, Combobox } from '@headlessui/react'
 import { useRouter } from 'next/router'
 
-export interface SearchProps {
-  fuse: Fuse<SearchItem>
-}
+export interface SearchProps {}
 
 interface SearchResultProps {
-  result: Fuse.FuseResult<SearchItem>
+  result: FuseResult<SearchItem>
   selected: boolean
   active: boolean
 }
@@ -40,6 +38,7 @@ const SearchResult: React.FunctionComponent<SearchResultProps> = (props) => {
 
   return (
     <div className={`m-1 rounded flex flex-col p-2 ${selection}`}>
+      <hr className="border-black/10 dark:border-white/10 mb-2"/>
       <div className="flex justify-between">
         <div>
           <code className="text-lg p-1 mx-1 bg-fuchsia-200 dark:bg-fuchsia-900 font-bold">
@@ -51,18 +50,31 @@ const SearchResult: React.FunctionComponent<SearchResultProps> = (props) => {
         </div>
       </div>
       <div>
-        <p>{excerpt(props.result.item.desc)}</p>
+        <p className="w-11/12">{excerpt(props.result.item.desc)}</p>
       </div>
     </div>
   )
 }
 
-const Search: React.FunctionComponent<SearchProps> = ({ fuse }) => {
+const Search: React.FunctionComponent<SearchProps> = () => {
   const router = useRouter()
   const [searchText, setSearchText] = useState('')
-  const [searchResults, setSearchResults] = useState<
-    Fuse.FuseResult<SearchItem>[]
-  >([])
+  const [searchResults, setSearchResults] = useState<FuseResult<SearchItem>[]>(
+    []
+  )
+  const [fuse, setFuse] = React.useState<Fuse<SearchItem> | undefined>(
+    undefined
+  )
+  const fusePromise = async () => {
+    const data = await fetch('/static/fuse-index.json')
+    console.log(data)
+    const searchIndex: SearchIndex = await data.json()
+    console.log(searchIndex)
+    return new Fuse(searchIndex.list, {}, Fuse.parseIndex(searchIndex.index))
+  }
+  React.useEffect(() => {
+    fusePromise().then((fuse) => setFuse(fuse))
+  }, [])
 
   const [isOpen, setIsOpen] = useState(false)
   const handleKeyPress = useCallback(
@@ -89,12 +101,20 @@ const Search: React.FunctionComponent<SearchProps> = ({ fuse }) => {
     }
   }, [handleKeyPress])
 
+  if (!fuse) {
+    return (
+      <div className="flex items-center ml-2">
+        <SearchIcon size={32} />
+      </div>
+    )
+  }
+
   const setSearch = (value: string) => {
     setSearchText(value)
     const searchResult = fuse.search(value)
     setSearchResults(searchResult)
   }
-  const onChange = (value?: Fuse.FuseResult<SearchItem>) => {
+  const onChange = (value?: FuseResult<SearchItem>) => {
     if (value) {
       if (value.item.kind === 'var') {
         router.push(`/variables#${value.item.name}`, undefined, {
